@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -102,7 +102,7 @@ namespace TimblServer {
   }
 
   bool ClientClass::setBase( const string& base ){
-    cout << "Setting base to :" << base << endl;
+    //    cout << "Setting base to :" << base << endl;
     if ( bases.find( base ) == bases.end() ){
       cerr << "'" << base << "' is not a valid base." << endl;
       return false;
